# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-02 16:28
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0006_auto_20180701_2128'),
    ]

    operations = [
        migrations.RenameField(
            model_name='userextension',
            old_name='defaultCurrency',
            new_name='default_currency',
        ),
        migrations.RenameField(
            model_name='userextension',
            old_name='defaultTemplateSet',
            new_name='default_template_set',
        ),
    ]
