# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-27 20:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculated Price With Tax'),
        ),
    ]
