# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-05 17:02
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ('crm', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('accounting', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='booking',
            name='bookingReference',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to='crm.Invoice', verbose_name='Booking Reference'),
        ),
        migrations.AddField(
            model_name='booking',
            name='fromAccount',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_fromaccount',
                                    to='accounting.Account', verbose_name='From Account'),
        ),
        migrations.AddField(
            model_name='booking',
            name='lastmodifiedby',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE,
                                    related_name='db_booking_lstmodified', to=settings.AUTH_USER_MODEL,
                                    verbose_name='Last modified by'),
        ),
        migrations.AddField(
            model_name='booking',
            name='staff',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE,
                                    related_name='db_booking_refstaff', to=settings.AUTH_USER_MODEL,
                                    verbose_name='Reference Staff'),
        ),
        migrations.AddField(
            model_name='booking',
            name='toAccount',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_toaccount',
                                    to='accounting.Account', verbose_name='To Account'),
        ),
    ]
