# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-09 19:49
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0002_auto_20170927_2042'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contact',
            options={'verbose_name': 'Kontakt', 'verbose_name_plural': 'Kontakt'},
        ),
        migrations.AlterModelOptions(
            name='contract',
            options={'verbose_name': 'Auftrag', 'verbose_name_plural': 'Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='currency',
            options={'verbose_name': 'Währung', 'verbose_name_plural': 'Währung'},
        ),
        migrations.AlterModelOptions(
            name='customer',
            options={'verbose_name': 'Kunde', 'verbose_name_plural': 'Kunden'},
        ),
        migrations.AlterModelOptions(
            name='customerbillingcycle',
            options={'verbose_name': 'Zahlungsbedingungen', 'verbose_name_plural': 'Zahlungsbedingungen'},
        ),
        migrations.AlterModelOptions(
            name='customergroup',
            options={'verbose_name': 'Kundengruppe', 'verbose_name_plural': 'Kundengruppen'},
        ),
        migrations.AlterModelOptions(
            name='customergrouptransform',
            options={'verbose_name': 'Kundengruppe Preisumrechnung', 'verbose_name_plural': 'Kundengruppen Preisumrechnungen'},
        ),
        migrations.AlterModelOptions(
            name='emailaddress',
            options={'verbose_name': 'Email Adresse', 'verbose_name_plural': 'Email Adresse'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforcontact',
            options={'verbose_name': 'Email Adresse für Kontakte', 'verbose_name_plural': 'Email Adresse für Kontakte'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforcontract',
            options={'verbose_name': 'Email Adresse für Aufträge', 'verbose_name_plural': 'Email Adresse für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforpurchaseorder',
            options={'verbose_name': 'Email Adresse für Aufträge', 'verbose_name_plural': 'Email Adresse für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforsalescontract',
            options={'verbose_name': 'Email Adresse für Aufträge', 'verbose_name_plural': 'Email Adresse für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='invoice',
            options={'verbose_name': 'Rechnung', 'verbose_name_plural': 'Rechnungen'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddress',
            options={'verbose_name': 'Telefonnummer', 'verbose_name_plural': 'Telefonnummer'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforcontact',
            options={'verbose_name': 'Telefonnummer für Kontakte', 'verbose_name_plural': 'Telefonnummer für Kontakte'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforcontract',
            options={'verbose_name': 'Telefonnummer für Aufträge', 'verbose_name_plural': 'Telefonnummer für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforpurchaseorder',
            options={'verbose_name': 'Telefonnummer für Aufträge', 'verbose_name_plural': 'Telefonnummer für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforsalescontract',
            options={'verbose_name': 'Telefonnummer für Aufträge', 'verbose_name_plural': 'Telefonnummer für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='position',
            options={'verbose_name': 'Position', 'verbose_name_plural': 'Positionen'},
        ),
        migrations.AlterModelOptions(
            name='postaladdress',
            options={'verbose_name': 'Postadresse', 'verbose_name_plural': 'Postadresse'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforcontact',
            options={'verbose_name': 'Postadresse für Kontakte', 'verbose_name_plural': 'Postadresse für Kontakte'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforcontract',
            options={'verbose_name': 'Postadresse für Aufträge', 'verbose_name_plural': 'Postadresse für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforpurchaseorder',
            options={'verbose_name': 'Postadresse für Aufträge', 'verbose_name_plural': 'Postadresse für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforsalescontract',
            options={'verbose_name': 'Postadresse für Aufträge', 'verbose_name_plural': 'Postadresse für Aufträge'},
        ),
        migrations.AlterModelOptions(
            name='price',
            options={'verbose_name': 'Preis', 'verbose_name_plural': 'Preise'},
        ),
        migrations.AlterModelOptions(
            name='product',
            options={'verbose_name': 'Produkt', 'verbose_name_plural': 'Produkte'},
        ),
        migrations.AlterModelOptions(
            name='purchaseorder',
            options={'verbose_name': 'Bestellung', 'verbose_name_plural': 'Bestellung'},
        ),
        migrations.AlterModelOptions(
            name='purchaseorderposition',
            options={'verbose_name': 'Bestellung Position', 'verbose_name_plural': 'Bestellung Positionen'},
        ),
        migrations.AlterModelOptions(
            name='quote',
            options={'verbose_name': 'Offerte', 'verbose_name_plural': 'Offerten'},
        ),
        migrations.AlterModelOptions(
            name='salescontract',
            options={'verbose_name': 'Verkaufsauftrag', 'verbose_name_plural': 'Verkaufsaufträge'},
        ),
        migrations.AlterModelOptions(
            name='salescontractposition',
            options={'verbose_name': 'Verkaufsaufträg Position', 'verbose_name_plural': 'Verkaufsaufträge Positionen'},
        ),
        migrations.AlterModelOptions(
            name='supplier',
            options={'verbose_name': 'Lieferant', 'verbose_name_plural': 'Lieferant'},
        ),
        migrations.AlterModelOptions(
            name='tax',
            options={'verbose_name': 'Steuer', 'verbose_name_plural': 'Steuern'},
        ),
        migrations.AlterModelOptions(
            name='unit',
            options={'verbose_name': 'Masseinheit', 'verbose_name_plural': 'Masseinheiten'},
        ),
        migrations.AlterModelOptions(
            name='unittransform',
            options={'verbose_name': 'Einheiten Umrechnung', 'verbose_name_plural': 'Einheiten Umrechnungen'},
        ),
        migrations.AddField(
            model_name='purchaseorder',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last printed'),
        ),
        migrations.AddField(
            model_name='salescontract',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last printed'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='dateofcreation',
            field=models.DateTimeField(auto_now=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodification',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodifiedby',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Zuletzt geändert durch'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='name',
            field=models.CharField(max_length=300, verbose_name='Dateiname'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultSupplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Standard Lieferant'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultcurrency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Standard Währung'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultcustomer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Customer', verbose_name='Standard Kunde'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='description',
            field=models.TextField(verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodification',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_contractlstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Zuletzt geändert durch'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relcontractstaff', to=settings.AUTH_USER_MODEL, verbose_name='Mitarbeiter'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='description',
            field=models.CharField(max_length=100, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='rounding',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Rundung'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='shortName',
            field=models.CharField(max_length=3, verbose_name='Angezeigt nach dem Preis in der Position'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='defaultCustomerBillingCycle',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerBillingCycle', verbose_name='Standard Zahlungsbedingung'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='ismemberof',
            field=models.ManyToManyField(blank=True, to='crm.CustomerGroup', verbose_name='Ist Mitglied von'),
        ),
        migrations.AlterField(
            model_name='customerbillingcycle',
            name='name',
            field=models.CharField(max_length=300, verbose_name='Dateiname'),
        ),
        migrations.AlterField(
            model_name='customerbillingcycle',
            name='timeToPaymentDate',
            field=models.IntegerField(verbose_name='Tage bis zur Fälligkeit'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='factor',
            field=models.IntegerField(blank=True, null=True, verbose_name='Prismultiplikator zwischen der einen und der anderen Kundengruppe'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='fromCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromcustomergroup', to='crm.CustomerGroup', verbose_name='Von Masseinheit'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Produkt'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='toCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtocustomergroup', to='crm.CustomerGroup', verbose_name='Zu Masseinheit'),
        ),
        migrations.AlterField(
            model_name='emailaddress',
            name='email',
            field=models.EmailField(max_length=200, verbose_name='Email Adresse'),
        ),
        migrations.AlterField(
            model_name='emailaddressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Privat'), ('O', 'Geschäftlich'), ('P', 'Mobil Privat'), ('B', 'Mobil Geschäftlich')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='emailaddressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='emailaddressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='emailaddressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='payableuntil',
            field=models.DateField(verbose_name='Zahlbar bis'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='paymentBankReference',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Zahlungsreferenz der Bank'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='status',
            field=models.CharField(choices=[('P', 'Bezahlt'), ('C', 'Rechnung erstellt'), ('I', 'Rechung geschickt'), ('F', 'Erste Erinnerung geschickt'), ('R', 'Zweite Erinnerung geschickt'), ('U', 'Kunde kann nicht zahlen'), ('D', 'Gelöscht')], max_length=1),
        ),
        migrations.AlterField(
            model_name='phoneaddress',
            name='phone',
            field=models.CharField(max_length=20, verbose_name='Telefonnummer'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Privat'), ('O', 'Geschäftlich'), ('P', 'Mobil Privat'), ('B', 'Mobil Geschäftlich')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='position',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='position',
            name='discount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Rabatt'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Zuletzt berechneter Preis'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Zuletzt berechnete Steuer'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Datum der letze Preisberechnung'),
        ),
        migrations.AlterField(
            model_name='position',
            name='overwriteProductPrice',
            field=models.BooleanField(verbose_name='Überschreie Produkt Preis'),
        ),
        migrations.AlterField(
            model_name='position',
            name='positionNumber',
            field=models.IntegerField(verbose_name='Positionsnummer'),
        ),
        migrations.AlterField(
            model_name='position',
            name='positionPricePerUnit',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Preis pro Einheit'),
        ),
        migrations.AlterField(
            model_name='position',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Produkt'),
        ),
        migrations.AlterField(
            model_name='position',
            name='quantity',
            field=models.DecimalField(decimal_places=3, max_digits=10, verbose_name='Anzahl'),
        ),
        migrations.AlterField(
            model_name='position',
            name='sentOn',
            field=models.DateField(blank=True, null=True, verbose_name='Verschickt am'),
        ),
        migrations.AlterField(
            model_name='position',
            name='shipmentID',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Lieferungs ID'),
        ),
        migrations.AlterField(
            model_name='position',
            name='supplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Versandunternehmen'),
        ),
        migrations.AlterField(
            model_name='position',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Masseinheit'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline1',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Adresslinie 1'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline2',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Adresslinie 2'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline3',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Adresslinie 3'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline4',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Adresslinie 4'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='country',
            field=models.CharField(blank=True, choices=[('AF', 'Afghanistan'), ('AX', 'Aland Islands'), ('AL', 'Albanien'), ('DZ', 'Algerien'), ('AS', 'Amerikanisch-Samoa'), ('AD', 'Andorra'), ('AO', 'Angola'), ('AI', 'Anguilla'), ('AQ', 'Antarktis'), ('AG', 'Antigua und Barbuda'), ('AR', 'Argentinien'), ('AM', 'Armenien'), ('AW', 'Aruba'), ('AU', 'Australien'), ('AT', 'Österreich'), ('AZ', 'Aserbaidschan'), ('BS', 'Bahamas'), ('BH', 'Bahrain\t'), ('BD', 'Bangladesch'), ('BB', 'Barbados'), ('BY', 'Belarus, (Weißrußland)'), ('BE', 'Belgien'), ('BZ', 'Belize'), ('BJ', 'Benin'), ('BM', 'Bermuda'), ('BT', 'Bhutan'), ('BO', 'Bolivien'), ('BA', 'Bosnien und Herzegovina'), ('BW', 'Botsuana'), ('BV', 'Bouvetinsel'), ('BR', 'Brasilien'), ('IO', 'Britisches Territorium im Indischen Ozean'), ('BN', 'Brunei Darussalam'), ('BG', 'Bulgarien'), ('BF', 'Burkina Faso (Obervolta - 1984)'), ('BI', 'Burundi'), ('KH', 'Kambodscha'), ('CM', 'Kamerun'), ('CA', 'Kanada'), ('CV', 'Kap Verde'), ('KY', 'Kaimaninseln'), ('CF', 'Zentralafrikanische Republik'), ('TD', 'Tschad'), ('CL', 'Chile'), ('CN', 'China'), ('CX', 'Weihnachtsinsel'), ('CC', 'Kokosinseln (Keeling)'), ('CO', 'Kolumbien'), ('KM', 'Komoren'), ('CG', 'Kongo'), ('CD', 'Kongo, Demokratische Republik'), ('CK', 'Cookinseln'), ('CR', 'Costa Rica'), ('CI', 'Elfenbeinküste'), ('HR', 'Kroatien'), ('CU', 'Kuba'), ('CY', 'Zypern'), ('CZ', 'Tschechische Republik'), ('DK', 'Dänemark'), ('DJ', 'Dschibuti'), ('DM', 'Dominica'), ('DO', 'Dominikanische Republik (Dom Rep)'), ('EC', 'Ecuador'), ('EG', 'Ägypten'), ('SV', 'El Salvador'), ('GQ', 'Äquatorialguinea'), ('ER', 'Eritrea'), ('EE', 'Estland'), ('ET', 'Äthiopien'), ('FK', 'Falklandinseln (Malvinen)'), ('FO', 'Färöer'), ('FJ', 'Fidschi'), ('FI', 'Finnland'), ('FR', 'Frankreich'), ('GF', 'Französisch-Guayana'), ('PF', 'Französisch-Polynesien'), ('TF', 'Französische Süd- und Antarktisgebiete'), ('GA', 'Gabun'), ('GM', 'Gambia'), ('GE', 'Georgien'), ('DE', 'Deutschland'), ('GH', 'Ghana'), ('GI', 'Gibraltar'), ('GR', 'Griechenland'), ('GL', 'Grönland'), ('GD', 'Grenada'), ('GP', 'Guadeloupe'), ('GU', 'Guam'), ('GT', 'Guatemala'), ('GG', 'Guernsey'), ('GN', 'Guinea'), ('GW', 'Guinea-Bissau'), ('GY', 'Guyana'), ('HT', 'Haiti'), ('HM', 'Heard und die Mcdonaldinseln'), ('VA', 'Heiliger Stuhl (Vatikanstadt)'), ('HN', 'Honduras'), ('HK', 'Hongkong'), ('HU', 'Ungarn'), ('IS', 'Island'), ('IN', 'Indien'), ('ID', 'Indonesien'), ('IR', 'Iran, Islamische Republik'), ('IQ', 'Irak'), ('IE', 'Irland'), ('IM', 'Insel Man'), ('IL', 'Israel'), ('IT', 'Italien'), ('JM', 'Jamaika'), ('JP', 'Japan'), ('JE', 'Jersey'), ('JO', 'Jordanien'), ('KZ', 'Kasachstan'), ('KE', 'Kenya'), ('KI', 'Kiribati'), ('KP', 'Korea, Demokratische Volksrepublik (Nord Korea)'), ('KR', 'Korea, Republik (Süd Korea)'), ('KW', 'Kuwait'), ('KG', 'Kirgisistan'), ('LA', 'Laos, Demokratische Volksrepublik'), ('LV', 'Lettland'), ('LB', 'Libanon'), ('LS', 'Lesotho'), ('LR', 'Liberia'), ('LY', 'Libyen, Libysch-Arabische Dschamahirija'), ('LI', 'Liechtenstein'), ('LT', 'Litauen'), ('LU', 'Luxemburg'), ('MO', 'Macau'), ('MK', 'Mazedonien'), ('MG', 'Madagaskar'), ('MW', 'Malawi'), ('MY', 'Malaysia'), ('MV', 'Malediven'), ('ML', 'Mali'), ('MT', 'Malta'), ('MH', 'Marshallinseln'), ('MQ', 'Martinique'), ('MR', 'Mauretanien'), ('MU', 'Mauritius'), ('YT', 'Mayotte'), ('MX', 'Mexiko'), ('FM', 'Mikronesien, Föderierte Staaten von'), ('MD', 'Moldau, Republik'), ('MC', 'Monaco'), ('MN', 'Mongolei'), ('ME', 'Montenegro'), ('MS', 'Montenegro'), ('MA', 'Marokko'), ('MZ', 'Mosambik'), ('MM', 'Myanmar, Birma'), ('NA', 'Namibia'), ('NR', 'Nauru'), ('NP', 'Nepal'), ('NL', 'Niederlande'), ('AN', 'Niederländische Antillen'), ('NC', 'Neukaledonien'), ('NZ', 'Neuseeland'), ('NI', 'Nicaragua'), ('NE', 'Niger'), ('NG', 'Nigeria'), ('NU', 'Niue'), ('NF', 'Norfolkinsel'), ('MP', 'Marianen, Nördliche'), ('NO', 'Norwegen'), ('OM', 'Oman'), ('PK', 'Pakistan'), ('PW', 'Palau'), ('PS', 'Palästinensische Autonomiegebiete'), ('PA', 'Panama'), ('PG', 'Papua-Neuguinea'), ('PY', 'Paraguay'), ('PE', 'Peru'), ('PH', 'Philippinen'), ('PN', 'Pitcairninseln'), ('PL', 'Polen'), ('PT', 'Portugal'), ('PR', 'Puerto Rico'), ('QA', 'Katar'), ('RE', 'Reunion'), ('RO', 'Rumänien'), ('RU', 'Russische Föderation (Russland)'), ('RW', 'Ruanda'), ('SH', 'St. Helena'), ('KN', 'St. Kitts und Nevis'), ('LC', 'St. Lucia'), ('PM', 'St. Pierre und Miquelon'), ('VC', 'St. Vincent und die Grenadinen'), ('WS', 'Samoa'), ('SM', 'San Marino'), ('ST', 'São Tomé und Príncipe'), ('SA', 'Saudi-Arabien'), ('SN', 'Senegal'), ('RS', 'Serbien'), ('SC', 'Seychellen'), ('SL', 'Sierra Leone'), ('SG', 'Singapur'), ('SK', 'Slowakei'), ('SI', 'Slowenien'), ('SB', 'Salomonen'), ('SO', 'Somalia'), ('ZA', 'Südafrika'), ('GS', 'Südgeorgien und die südlichen Sandwichinseln'), ('ES', 'Spanien'), ('LK', 'Sri Lanka'), ('SD', 'Sudan'), ('SR', 'Suriname'), ('SJ', 'Svalbard und Jan Mayen'), ('SZ', 'Swasiland'), ('SE', 'Schweden'), ('CH', 'Schweiz'), ('SY', 'Syrien, Arabische Republik'), ('TW', 'Taiwan'), ('TJ', 'Tadschikistan'), ('TZ', 'Tansania, Vereinigte Republik'), ('TH', 'Thailand'), ('TL', 'Timor-Leste (Osttimor)'), ('TG', 'Togo'), ('TK', 'Tokelau'), ('TO', 'Tonga'), ('TT', 'Trinidad und Tobago'), ('TN', 'Tunesien'), ('TR', 'Türkei'), ('TM', 'Turkmenistan'), ('TC', 'Turks- und Caicosinseln'), ('TV', 'Tuvalu'), ('UG', 'Uganda'), ('UA', 'Ukraine'), ('AE', 'Vereinigte Arabische Emirate'), ('GB', 'Vereinigtes Königreich'), ('US', 'Vereinigte Staaten'), ('UM', 'Amerikanische Überseeinseln, Kleinere'), ('UY', 'Uruguay'), ('UZ', 'Usbekistan'), ('VU', 'Vanuatu'), ('VE', 'Venezuela'), ('VN', 'Vietnam'), ('VG', 'Britische Jungferninseln'), ('VI', 'Amerikanische Jungferninseln'), ('WF', 'Wallis und Futuna'), ('EH', 'Westsahara'), ('YE', 'Jemen'), ('ZM', 'Sambia'), ('ZW', 'Simbabwe')], max_length=2, null=True, verbose_name='Land'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Dateiname'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='prefix',
            field=models.CharField(blank=True, choices=[('F', 'Firma'), ('W', 'Frau'), ('H', 'Herr'), ('G', 'Frau')], max_length=1, null=True, verbose_name='Anrede'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='prename',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Vorname'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='state',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Bundestaat/Kanton'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='town',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Ortschaft'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='zipcode',
            field=models.IntegerField(blank=True, null=True, verbose_name='PLZ'),
        ),
        migrations.AlterField(
            model_name='postaladdressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Privat'), ('O', 'Geschäftlich'), ('P', 'Mobil Privat'), ('B', 'Mobil Geschäftlich')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='postaladdressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='postaladdressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='postaladdressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Versand Addresse'), ('B', 'Rechnungs Adresse'), ('C', 'Kontakt Adresse')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='price',
            name='customerGroup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerGroup', verbose_name='Kundengruppe'),
        ),
        migrations.AlterField(
            model_name='price',
            name='price',
            field=models.DecimalField(decimal_places=2, max_digits=17, verbose_name='Preis pro Einheit'),
        ),
        migrations.AlterField(
            model_name='price',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Produkt'),
        ),
        migrations.AlterField(
            model_name='price',
            name='unit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Masseinheit'),
        ),
        migrations.AlterField(
            model_name='price',
            name='validfrom',
            field=models.DateField(blank=True, null=True, verbose_name='Gültig vom'),
        ),
        migrations.AlterField(
            model_name='price',
            name='validuntil',
            field=models.DateField(blank=True, null=True, verbose_name='Gültig bis'),
        ),
        migrations.AlterField(
            model_name='product',
            name='accoutingProductCategorie',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, to='accounting.ProductCategorie', verbose_name='Buchhaltung Produktkategorie'),
        ),
        migrations.AlterField(
            model_name='product',
            name='dateofcreation',
            field=models.DateTimeField(auto_now=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='product',
            name='defaultunit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Masseinheit'),
        ),
        migrations.AlterField(
            model_name='product',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodification',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Zuletzt geändert durch'),
        ),
        migrations.AlterField(
            model_name='product',
            name='productNumber',
            field=models.IntegerField(verbose_name='Produktnummer'),
        ),
        migrations.AlterField(
            model_name='product',
            name='title',
            field=models.CharField(max_length=200, verbose_name='Titel'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Auftrag'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Währung'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='dateofcreation',
            field=models.DateTimeField(auto_now=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='description',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='externalReference',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Externe Referenz'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Zuletzt berechneter Preis mit Steuer'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Zuletzt berechnete Steuer'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Datum der letze Preisberechnung'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodification',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_polstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Zuletzt geändert durch'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relpostaff', to=settings.AUTH_USER_MODEL, verbose_name='Mitarbeiter'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='status',
            field=models.CharField(choices=[('O', 'Bestellt'), ('D', 'Verspätet'), ('Y', 'Ausgeliefert'), ('I', 'Rechnung registriert'), ('P', 'Rechnung bezahlt')], max_length=1),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='supplier',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Lieferant'),
        ),
        migrations.AlterField(
            model_name='purchaseorderposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder', verbose_name='Auftrag'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='status',
            field=models.CharField(choices=[('S', 'Erfolg'), ('I', 'Offerte erstellt'), ('Q', 'Offerte verschickt'), ('F', 'Erste Erinnerung geschickt'), ('R', 'Zweite Erinnerung geschickt'), ('D', 'Gelöscht')], max_length=1, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='validuntil',
            field=models.DateField(verbose_name='Gültig bis'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Auftrag'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Währung'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='customer',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Customer', verbose_name='Kunde'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='description',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='discount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Rabatt'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='externalReference',
            field=models.CharField(blank=True, max_length=100, verbose_name='Externe Referenz'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Preis ohne Steuer'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Steuer'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Letzte Preisberechnung'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodification',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_lstscmodified', to=settings.AUTH_USER_MODEL, verbose_name='Zuletzt geändert durch'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relscstaff', to=settings.AUTH_USER_MODEL, verbose_name='Mitarbeiter'),
        ),
        migrations.AlterField(
            model_name='salescontractposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract', verbose_name='Auftrag'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='accountActiva',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relaccountactiva', to='accounting.Account', verbose_name='Aktiv Konto'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='accountPassiva',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relaccountpassiva', to='accounting.Account', verbose_name='Passiv Konto'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='name',
            field=models.CharField(max_length=100, verbose_name='Name der Steuer'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='taxrate',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Steuersatz in Prozent'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='description',
            field=models.CharField(max_length=100, verbose_name='Beschreibung'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='fractionFactorToNextHigherUnit',
            field=models.IntegerField(blank=True, null=True, verbose_name='Multiplikator zwischen dieser und der nächst höheren Einheit'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='isAFractionOf',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Ist eine Untereinheit von'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='shortName',
            field=models.CharField(max_length=3, verbose_name='Angezeigt nach der Anzahl in der Position'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='factor',
            field=models.IntegerField(blank=True, null=True, verbose_name='Multiplikator zwischen der einen und der anderen Einheit'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='fromUnit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromunit', to='crm.Unit', verbose_name='Von Masseinheit'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Produkt'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='toUnit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtounit', to='crm.Unit', verbose_name='Zu Masseinheit'),
        ),
    ]
