# -*- coding: utf-8 -*-

from koalixcrm.crm.contact.contact import *
from koalixcrm.crm.contact.customer_group import *
from koalixcrm.crm.contact.customer import *
from koalixcrm.crm.contact.postal_address import *
from koalixcrm.crm.contact.customer_billing_cycle import *
from koalixcrm.crm.contact.email_address import *
from koalixcrm.crm.contact.phone_address import *
from koalixcrm.crm.contact.supplier import *

from koalixcrm.crm.documents.contract import Contract, PostalAddressForContract
from koalixcrm.crm.documents.contract import PhoneAddressForContract, EmailAddressForContract
from koalixcrm.crm.documents.sales_document_position import Position, SalesDocumentPosition
from koalixcrm.crm.documents.sales_document import SalesDocument, PostalAddressForSalesDocument
from koalixcrm.crm.documents.sales_document import EmailAddressForSalesDocument, PhoneAddressForSalesDocument
from koalixcrm.crm.documents.sales_document import TextParagraphInSalesDocument
from koalixcrm.crm.documents.invoice import Invoice
from koalixcrm.crm.documents.purchase_confirmation import PurchaseConfirmation
from koalixcrm.crm.documents.purchase_order import PurchaseOrder
from koalixcrm.crm.documents.quote import Quote
from koalixcrm.crm.documents.payment_reminder import PaymentReminder
from koalixcrm.crm.documents.delivery_note import DeliveryNote

from koalixcrm.crm.product.currency import *
from koalixcrm.crm.product.price import *
from koalixcrm.crm.product.product import *
from koalixcrm.crm.product.product_type import *
from koalixcrm.crm.product.product_price import *
from koalixcrm.crm.product.customer_group_transform import *
from koalixcrm.crm.product.unit_transform import *
from koalixcrm.crm.product.tax import *
from koalixcrm.crm.product.unit import *

from koalixcrm.crm.reporting.agreement import *
from koalixcrm.crm.reporting.agreement_status import *
from koalixcrm.crm.reporting.agreement_type import *
from koalixcrm.crm.reporting.agreement_status import *
from koalixcrm.crm.reporting.estimation import *
from koalixcrm.crm.reporting.estimation_status import *
from koalixcrm.crm.reporting.human_resource import *
from koalixcrm.crm.reporting.resource_manager import *
from koalixcrm.crm.reporting.resource_type import *
from koalixcrm.crm.reporting.resource_price import *
from koalixcrm.crm.reporting.generic_task_link import *
from koalixcrm.crm.reporting.task import *
from koalixcrm.crm.reporting.task_link_type import *
from koalixcrm.crm.reporting.task_status import *
from koalixcrm.crm.reporting.work import *
from koalixcrm.crm.reporting.project import *
from koalixcrm.crm.reporting.project_link_type import *
from koalixcrm.crm.reporting.project_status import *
from koalixcrm.crm.reporting.generic_project_link import *
from koalixcrm.crm.reporting.reporting_period import *
from koalixcrm.crm.reporting.reporting_period_status import *






