# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-10-20 18:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0053_auto_20181014_2305'),
    ]

    operations = [
        migrations.AlterField(
            model_name='currency',
            name='short_name',
            field=models.CharField(max_length=3, verbose_name='Displayed Name After Prices'),
        ),
    ]
