# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-04 20:42
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0004_auto_20171210_2126'),
        ('crm', '0007_auto_20171210_2126'),
    ]

    operations = [
        migrations.RenameField(
            model_name='textparagraphinsalescontract',
            old_name='SalesContract',
            new_name='sales_contract',
        ),
        migrations.AddField(
            model_name='contract',
            name='default_template_set',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.TemplateSet', verbose_name='Default Template Set'),
        ),
    ]
