{% extends "admin/base.html" %}
{% block title %}
Create Work Report
{% endblock %}

{% block content %}

<form action="" method="post">{% csrf_token %}
    <table>
        {% for obj in queryset %}
        <tr>
            <td>
                Select date that the report shall cover:
            </td>
            {{ form }}
        </tr>
        <tr>
            <td>
                <input type="hidden" name="{{ action_checkbox_name }}" value="{{ obj.pk }}"/>
                <input type="hidden" name="action" value="create_work_report_pdf"/>
                <input type="hidden" name="post" value="yes"/>
                <input type="submit" name="cancel" value="cancel"/>
                <input type="submit" name="create_pdf" value="create_pdf"/>
            </td>
        </tr>
    </table>
    {% endfor %}
</form>
{% endblock %}

