# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-17 20:20
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0021_purchaseorder'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='purchaseorder',
            options={'verbose_name': 'Purchase Order', 'verbose_name_plural': 'Purchase Orders'},
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='supplier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Supplier'),
        ),
    ]
