# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-07 12:40
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('accounting', '0002_auto_20170705_1702'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='account',
            name='originalAmount',
        ),
    ]
