# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-06-12 19:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0004_auto_20171210_2126'),
    ]

    operations = [
        migrations.CreateModel(
            name='MonthlyProjectSummaryTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Monthly project summary template',
                'verbose_name_plural': 'Monthly project summary templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.AddField(
            model_name='templateset',
            name='monthly_project_summary_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.MonthlyProjectSummaryTemplate'),
        ),
    ]
