# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-12 20:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0018_auto_20180111_2031'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='emailaddressforsalesdocument',
            options={'verbose_name': 'Email Address For Sales Documents', 'verbose_name_plural': 'Email Address For Sales Documents'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforsalesdocument',
            options={'verbose_name': 'Phone Address For Sales Documents', 'verbose_name_plural': 'Phone Address For Sales Documents'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforsalesdocument',
            options={'verbose_name': 'Postal Address For Sales Documents', 'verbose_name_plural': 'Postal Address For Sales Documents'},
        ),
        migrations.RenameField(
            model_name='customerbillingcycle',
            old_name='timeToPaymentDate',
            new_name='time_to_payment_date',
        ),
        migrations.RemoveField(
            model_name='deliverynote',
            name='derived_from_invoice',
        ),
        migrations.RemoveField(
            model_name='deliverynote',
            name='derived_from_quote',
        ),
        migrations.RemoveField(
            model_name='paymentreminder',
            name='derived_from_invoice',
        ),
        migrations.RemoveField(
            model_name='purchaseconfirmation',
            name='derived_from_quote',
        ),
        migrations.AddField(
            model_name='customerbillingcycle',
            name='payment_reminder_time_to_payment',
            field=models.IntegerField(default=10, verbose_name='Payment Reminder, Days To Payment Date '),
            preserve_default=False,
        ),
    ]
