# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-11 20:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0015_auto_20180111_2043'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='EmailAddressForSalesContract',
            new_name='EmailAddressForSalesDocument'
        ),
        migrations.RenameModel(
            old_name='PhoneAddressForSalesContract',
            new_name='PhoneAddressForSalesDocument',
        ),
        migrations.RenameModel(
            old_name='PostalAddressForSalesContract',
            new_name='PostalAddressForSalesDocument',
        ),
        migrations.RenameModel(
            old_name='SalesContractPosition',
            new_name='SalesDocumentPosition',
        ),
        migrations.RenameModel(
            old_name='TextParagraphInSalesContract',
            new_name='TextParagraphInSalesDocument',
        ),
        migrations.AddField(
            model_name='salesdocument',
            name='derived_from_sales_document',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.SalesDocument'),
        ),
    ]
