# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-09 19:49
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subscription',
            options={'verbose_name': 'Abonnement', 'verbose_name_plural': 'Abonnemente'},
        ),
        migrations.AlterModelOptions(
            name='subscriptionevent',
            options={'verbose_name': 'Abonnement Ereignis', 'verbose_name_plural': 'Abonnement Ereignisse'},
        ),
        migrations.AlterModelOptions(
            name='subscriptiontype',
            options={'verbose_name': 'Abonnement Typ', 'verbose_name_plural': 'Abonnement Typen'},
        ),
        migrations.AlterField(
            model_name='subscription',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Abonnement Typ'),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='subscriptiontype',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='subscriptions.SubscriptionType', verbose_name='Abonnement Typ'),
        ),
        migrations.AlterField(
            model_name='subscriptionevent',
            name='event',
            field=models.CharField(choices=[('O', 'Offeriert'), ('C', 'Aufgelöst'), ('S', 'Unterschrieben')], max_length=1, verbose_name='Ereignis'),
        ),
        migrations.AlterField(
            model_name='subscriptionevent',
            name='eventdate',
            field=models.DateField(blank=True, null=True, verbose_name='Ereignis Datum'),
        ),
        migrations.AlterField(
            model_name='subscriptionevent',
            name='subscriptions',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='subscriptions.Subscription', verbose_name='Abonnement'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='automaticContractExtension',
            field=models.IntegerField(blank=True, null=True, verbose_name='Automatische Vertragsverlängerung in Monaten'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='automaticContractExtensionReminder',
            field=models.IntegerField(blank=True, null=True, verbose_name='Automatische Vertragsverlängerung Erinnerung in Tagen'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='cancelationPeriod',
            field=models.IntegerField(blank=True, null=True, verbose_name='Kündigungsfirst in Monaten'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='contractDocument',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='Vertragsdokumente'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='minimumDuration',
            field=models.IntegerField(blank=True, null=True, verbose_name='Minimale Vertragsdauer'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='paymentIntervall',
            field=models.IntegerField(blank=True, null=True, verbose_name='Zahlungsintervall'),
        ),
    ]
