# -*- coding: utf-8 -*

from django.utils.translation import ugettext as _

ACCOUNTTYPECHOICES = (
    ('E', _('Earnings')),
    ('S', _('Spendings')),
    ('L', _('Liabilities')),
    ('A', _('Assets')),
)
