# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-09 19:49
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='templateset',
            options={'verbose_name': 'Vorlagenset', 'verbose_name_plural': 'Vorlagensets'},
        ),
        migrations.AlterModelOptions(
            name='userextension',
            options={'verbose_name': 'Benutzer Erweiterung', 'verbose_name_plural': 'Benutzer Erweiterungen'},
        ),
        migrations.AlterModelOptions(
            name='xslfile',
            options={'verbose_name': 'XSL Datei', 'verbose_name_plural': 'XSL Dateien'},
        ),
        migrations.AlterField(
            model_name='templateset',
            name='addresser',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Absender'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='balancesheetXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatebalancesheet', to='djangoUserExtension.XSLFile', verbose_name='XSL Datei für die Billanz'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='bankingaccountref',
            field=models.CharField(blank=True, max_length=60, null=True, verbose_name='Bankverbindung'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='deilveryorderXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatedeliveryorder', to='djangoUserExtension.XSLFile', verbose_name='XSL Datei für den Lieferschein'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='footerTextpurchaseorders',
            field=models.TextField(blank=True, null=True, verbose_name='Grussfromel für die Kaufaufträge'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='footerTextsalesorders',
            field=models.TextField(blank=True, null=True, verbose_name='Grussfromel für die Verkaufsaufträge'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='fopConfigurationFile',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='FOP Configurations Datei'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='headerTextpurchaseorders',
            field=models.TextField(blank=True, null=True, verbose_name='Begrüssungsformel für die Kaufaufträge'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='headerTextsalesorders',
            field=models.TextField(blank=True, null=True, verbose_name='Begrüssungsfromel für die Verkaufsaufträge'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='invoiceXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplateinvoice', to='djangoUserExtension.XSLFile', verbose_name='XSL Datei für die Rechnung'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='logo',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name="Logo für die PDF's"),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='organisationname',
            field=models.CharField(max_length=200, verbose_name='Name der Organisation'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='pagefooterleft',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='Fussnote Links'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='pagefootermiddle',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='Fussnote Mitte'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='profitLossStatementXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplateprofitlossstatement', to='djangoUserExtension.XSLFile', verbose_name='XSL Datei für die Erfolgsrechung'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='purchaseorderXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepurchaseorder', to='djangoUserExtension.XSLFile', verbose_name='XSL Datei für die Kaufsbestätigung'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='quoteXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatequote', to='djangoUserExtension.XSLFile', verbose_name='XSL Datei für die Offerte'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='title',
            field=models.CharField(max_length=100, verbose_name='Titel'),
        ),
        migrations.AlterField(
            model_name='userextensionemailaddress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Privat'), ('O', 'Geschäftlich'), ('P', 'Mobil Privat'), ('B', 'Mobil Geschäftlich')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='userextensionphoneaddress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Privat'), ('O', 'Geschäftlich'), ('P', 'Mobil Privat'), ('B', 'Mobil Geschäftlich')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='userextensionpostaladdress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Privat'), ('O', 'Geschäftlich'), ('P', 'Mobil Privat'), ('B', 'Mobil Geschäftlich')], max_length=1, verbose_name='Verwendungszweck'),
        ),
        migrations.AlterField(
            model_name='xslfile',
            name='title',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Titel'),
        ),
        migrations.AlterField(
            model_name='xslfile',
            name='xslfile',
            field=filebrowser.fields.FileBrowseField(max_length=200, verbose_name='XSL Datei'),
        ),
    ]
