{% extends "admin/base.html" %}

{% block title %}
Change Timezone
{% endblock %}
{% block content %}
    {% load tz %}
    {% get_current_timezone as TIME_ZONE %}
    <form action="{% url 'set_timezone' %}" method="POST">
        {% csrf_token %}
        <label for="timezone">Time zone:</label>
        <select name="timezone">
            {% for tz in timezones %}
            <option value="{{ tz }}"{% if tz == TIME_ZONE %} selected{% endif %}>{{ tz }}</option>
            {% endfor %}
        </select>
        <input type="submit" value="Set">
    </form>
{% endblock%}

