# Generated by Django 2.1.5 on 2019-01-06 15:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0056_auto_20190102_2230'),
        ('crm', '0056_auto_20181216_2224'),
    ]

    operations = [
    ]
