# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-10 17:32
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0004_auto_20171009_1949'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='account',
            options={'ordering': ['accountNumber'], 'verbose_name': 'Account', 'verbose_name_plural': 'Account'},
        ),
        migrations.AlterModelOptions(
            name='accountingperiod',
            options={'verbose_name': 'Accounting Period', 'verbose_name_plural': 'Accounting Periods'},
        ),
        migrations.AlterModelOptions(
            name='booking',
            options={'verbose_name': 'Booking', 'verbose_name_plural': 'Bookings'},
        ),
        migrations.AlterModelOptions(
            name='productcategorie',
            options={'verbose_name': 'Product Categorie', 'verbose_name_plural': 'Product Categories'},
        ),
        migrations.AlterField(
            model_name='account',
            name='accountNumber',
            field=models.IntegerField(verbose_name='Account Number'),
        ),
        migrations.AlterField(
            model_name='account',
            name='accountType',
            field=models.CharField(choices=[('E', 'Earnings'), ('S', 'Spendings'), ('L', 'Liabilities'), ('A', 'Assets')], max_length=1, verbose_name='Account Type'),
        ),
        migrations.AlterField(
            model_name='account',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='account',
            name='isACustomerPaymentAccount',
            field=models.BooleanField(verbose_name='Is a Customer Payment Account'),
        ),
        migrations.AlterField(
            model_name='account',
            name='isProductInventoryActiva',
            field=models.BooleanField(verbose_name='Is a Product Inventory Account'),
        ),
        migrations.AlterField(
            model_name='account',
            name='isopeninterestaccount',
            field=models.BooleanField(verbose_name='Is The Open Interests Account'),
        ),
        migrations.AlterField(
            model_name='account',
            name='isopenreliabilitiesaccount',
            field=models.BooleanField(verbose_name='Is The Open Liabilities Account'),
        ),
        migrations.AlterField(
            model_name='account',
            name='title',
            field=models.CharField(max_length=50, verbose_name='Account Title'),
        ),
        migrations.AlterField(
            model_name='accountingperiod',
            name='begin',
            field=models.DateField(verbose_name='Begin'),
        ),
        migrations.AlterField(
            model_name='accountingperiod',
            name='end',
            field=models.DateField(verbose_name='End'),
        ),
        migrations.AlterField(
            model_name='accountingperiod',
            name='title',
            field=models.CharField(max_length=200, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='accountingPeriod',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='accounting.AccountingPeriod', verbose_name='AccountingPeriod'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='amount',
            field=models.DecimalField(decimal_places=2, max_digits=20, verbose_name='Amount'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='bookingDate',
            field=models.DateTimeField(verbose_name='Booking at'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='bookingReference',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Invoice', verbose_name='Booking Reference'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='dateofcreation',
            field=models.DateTimeField(auto_now=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='description',
            field=models.CharField(blank=True, max_length=120, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='fromAccount',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_fromaccount', to='accounting.Account', verbose_name='From Account'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='lastmodification',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='lastmodifiedby',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_lstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='staff',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_refstaff', to=settings.AUTH_USER_MODEL, verbose_name='Reference Staff'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='toAccount',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_toaccount', to='accounting.Account', verbose_name='To Account'),
        ),
        migrations.AlterField(
            model_name='productcategorie',
            name='lossAccount',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_loss_account', to='accounting.Account', verbose_name='Loss Account'),
        ),
        migrations.AlterField(
            model_name='productcategorie',
            name='profitAccount',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_profit_account', to='accounting.Account', verbose_name='Profit Account'),
        ),
        migrations.AlterField(
            model_name='productcategorie',
            name='title',
            field=models.CharField(max_length=50, verbose_name='Product Categorie Title'),
        ),
    ]
