# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-27 16:19
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0043_reportingperiodstatus'),
    ]

    operations = [
        migrations.AddField(
            model_name='reportingperiod',
            name='status',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.ReportingPeriodStatus', verbose_name='Reporting Period Status'),
        ),
    ]
