# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-09 20:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0003_auto_20171009_1949'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contact',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='product',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Zuletzt gedruckt'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Erstelldatum'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Zuletzt gedruckt'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Zuletzt geändert'),
        ),
    ]
