# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-01 21:28
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0036_auto_20180626_2059'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='reportingperiod',
            options={'verbose_name': 'Reporting Period', 'verbose_name_plural': 'Reporting Periods'},
        ),
    ]
