# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-16 20:56
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0019_auto_20180112_2020'),
    ]

    operations = [
        migrations.DeleteModel(
            name='PurchaseOrder',
        ),
        migrations.DeleteModel(
            name='EmailAddressForPurchaseOrder',
        ),
        migrations.DeleteModel(
            name='PhoneAddressForPurchaseOrder',
        ),
        migrations.DeleteModel(
            name='PostalAddressForPurchaseOrder',
        ),
        migrations.DeleteModel(
            name='PurchaseOrderPosition',
        ),
    ]
