# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-10-12 20:56
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models

class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0007_auto_20180702_1628'),
        ('accounting', '0008_auto_20181012_2056'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('crm', '0047_work_worked_hours'),
        ('subscriptions', '0004_auto_20181013_2213')
    ]

    operations = [
        migrations.AddField(
            model_name='customergrouptransform',
            name='product_backup',
            field=models.IntegerField(blank=True, null=True, verbose_name='Product Backup Identifier'),
        ),
        migrations.AddField(
            model_name='position',
            name='product_backup',
            field=models.IntegerField(blank=True, null=True, verbose_name='Product Backup Identifier'),
        ),
        migrations.AddField(
            model_name='unittransform',
            name='product_backup',
            field=models.IntegerField(blank=True, null=True, verbose_name='Product Backup Identifier'),
        ),
        migrations.AddField(
            model_name='price',
            name='product_backup',
            field=models.IntegerField(blank=True, null=True, verbose_name='Product Backup Identifier'),
        ),
    ]
