# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-06-11 19:30
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('crm', '0029_auto_20180611_1903'),
    ]

    operations = [
        migrations.AddField(
            model_name='generictasklink',
            name='date_of_creation',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='generictasklink',
            name='last_modified_by',
            field=models.ForeignKey(default=2, on_delete=django.db.models.deletion.CASCADE, related_name='db_task_link_last_modified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
            preserve_default=False,
        ),
    ]
