# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-02 16:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0038_auto_20180702_1628'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='person',
            name='prename',
        ),
        migrations.AddField(
            model_name='person',
            name='pre_name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Pre-name'),
        ),
    ]
