# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-08 20:48
from __future__ import unicode_literals
from django.db import migrations, models
import django.db.models.deletion

class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0013_auto_20180105_2159'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='invoice',
            name='derived_from_quote',
        ),
        migrations.AddField(
            model_name='salescontract',
            name='derived_from_sales_contract',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract'),
        ),
    ]
