# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-24 18:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0041_auto_20180724_1657'),
    ]

    operations = [
        migrations.AlterField(
            model_name='unit',
            name='fraction_factor_to_next_higher_unit',
            field=models.DecimalField(blank=True, decimal_places=10, max_digits=20, null=True, verbose_name='Factor Between This And Next Higher Unit'),
        ),
    ]
