# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-01 21:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0005_auto_20180612_1924'),
    ]

    operations = [
        migrations.CreateModel(
            name='WorkReportTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Work report template',
                'verbose_name_plural': 'Work report templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.AlterModelOptions(
            name='templateset',
            options={'verbose_name': 'Template-set', 'verbose_name_plural': 'Template-sets'},
        ),
        migrations.AlterModelOptions(
            name='userextension',
            options={'verbose_name': 'User Extension', 'verbose_name_plural': 'User Extension'},
        ),
        migrations.AlterModelOptions(
            name='userextensionemailaddress',
            options={'verbose_name': 'Email Address for User Extension', 'verbose_name_plural': 'Email Address for User Extension'},
        ),
        migrations.AlterModelOptions(
            name='userextensionphoneaddress',
            options={'verbose_name': 'Phone number for User Extension', 'verbose_name_plural': 'Phone number for User Extension'},
        ),
        migrations.AlterModelOptions(
            name='userextensionpostaladdress',
            options={'verbose_name': 'Postal Address for User Extension', 'verbose_name_plural': 'Postal Address for User Extension'},
        ),
        migrations.AddField(
            model_name='templateset',
            name='work_report_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.WorkReportTemplate'),
        ),
    ]
