# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-24 16:57
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0040_auto_20180724_1657'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tasks', to='crm.Project', verbose_name='Project'),
        ),
    ]
