# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-04-22 21:05
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0004_auto_20171210_2126'),
        ('accounting', '0006_auto_20180422_2048'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='accountingperiod',
            name='template_set',
        ),
        migrations.AddField(
            model_name='accountingperiod',
            name='template_profit_loss_statement',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_profit_loss_statement_template_set', to='djangoUserExtension.DocumentTemplate', verbose_name='Referred template for profit, loss statement'),
        ),
        migrations.AddField(
            model_name='accountingperiod',
            name='template_set_balance_sheet',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_balancesheet_template_set', to='djangoUserExtension.DocumentTemplate', verbose_name='Referred template for balance sheet'),
        ),
    ]
