# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-10 17:32
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0004_auto_20171009_2008'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contact',
            options={'verbose_name': 'Contact', 'verbose_name_plural': 'Contact'},
        ),
        migrations.AlterModelOptions(
            name='contract',
            options={'verbose_name': 'Contract', 'verbose_name_plural': 'Contracts'},
        ),
        migrations.AlterModelOptions(
            name='currency',
            options={'verbose_name': 'Currency', 'verbose_name_plural': 'Currency'},
        ),
        migrations.AlterModelOptions(
            name='customer',
            options={'verbose_name': 'Customer', 'verbose_name_plural': 'Customers'},
        ),
        migrations.AlterModelOptions(
            name='customerbillingcycle',
            options={'verbose_name': 'Customer Billing Cycle', 'verbose_name_plural': 'Customer Billing Cycle'},
        ),
        migrations.AlterModelOptions(
            name='customergroup',
            options={'verbose_name': 'Customer Group', 'verbose_name_plural': 'Customer Groups'},
        ),
        migrations.AlterModelOptions(
            name='customergrouptransform',
            options={'verbose_name': 'Customer Group Price Transfrom', 'verbose_name_plural': 'Customer Group Price Transfroms'},
        ),
        migrations.AlterModelOptions(
            name='emailaddress',
            options={'verbose_name': 'Email Address', 'verbose_name_plural': 'Email Address'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforcontact',
            options={'verbose_name': 'Email Address For Contact', 'verbose_name_plural': 'Email Address For Contact'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforcontract',
            options={'verbose_name': 'Email Address For Contracts', 'verbose_name_plural': 'Email Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforpurchaseorder',
            options={'verbose_name': 'Email Address For Contracts', 'verbose_name_plural': 'Email Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforsalescontract',
            options={'verbose_name': 'Email Address For Contracts', 'verbose_name_plural': 'Email Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='invoice',
            options={'verbose_name': 'Invoice', 'verbose_name_plural': 'Invoices'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddress',
            options={'verbose_name': 'Phone Address', 'verbose_name_plural': 'Phone Address'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforcontact',
            options={'verbose_name': 'Phone Address For Contact', 'verbose_name_plural': 'Phone Address For Contact'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforcontract',
            options={'verbose_name': 'Phone Address For Contracts', 'verbose_name_plural': 'Phone Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforpurchaseorder',
            options={'verbose_name': 'Phone Address For Contracts', 'verbose_name_plural': 'Phone Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforsalescontract',
            options={'verbose_name': 'Phone Address For Contracts', 'verbose_name_plural': 'Phone Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='position',
            options={'verbose_name': 'Position', 'verbose_name_plural': 'Positions'},
        ),
        migrations.AlterModelOptions(
            name='postaladdress',
            options={'verbose_name': 'Postal Address', 'verbose_name_plural': 'Postal Address'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforcontact',
            options={'verbose_name': 'Postal Address For Contact', 'verbose_name_plural': 'Postal Address For Contact'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforcontract',
            options={'verbose_name': 'Postal Address For Contracts', 'verbose_name_plural': 'Postal Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforpurchaseorder',
            options={'verbose_name': 'Postal Address For Contracts', 'verbose_name_plural': 'Postal Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforsalescontract',
            options={'verbose_name': 'Postal Address For Contracts', 'verbose_name_plural': 'Postal Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='price',
            options={'verbose_name': 'Price', 'verbose_name_plural': 'Prices'},
        ),
        migrations.AlterModelOptions(
            name='product',
            options={'verbose_name': 'Product', 'verbose_name_plural': 'Products'},
        ),
        migrations.AlterModelOptions(
            name='purchaseorder',
            options={'verbose_name': 'Purchase Order', 'verbose_name_plural': 'Purchase Order'},
        ),
        migrations.AlterModelOptions(
            name='purchaseorderposition',
            options={'verbose_name': 'Purchaseorder Position', 'verbose_name_plural': 'Purchaseorder Positions'},
        ),
        migrations.AlterModelOptions(
            name='quote',
            options={'verbose_name': 'Quote', 'verbose_name_plural': 'Quotes'},
        ),
        migrations.AlterModelOptions(
            name='salescontract',
            options={'verbose_name': 'Sales Contract', 'verbose_name_plural': 'Sales Contracts'},
        ),
        migrations.AlterModelOptions(
            name='salescontractposition',
            options={'verbose_name': 'Salescontract Position', 'verbose_name_plural': 'Salescontract Positions'},
        ),
        migrations.AlterModelOptions(
            name='supplier',
            options={'verbose_name': 'Supplier', 'verbose_name_plural': 'Supplier'},
        ),
        migrations.AlterModelOptions(
            name='tax',
            options={'verbose_name': 'Tax', 'verbose_name_plural': 'Taxes'},
        ),
        migrations.AlterModelOptions(
            name='unit',
            options={'verbose_name': 'Unit', 'verbose_name_plural': 'Units'},
        ),
        migrations.AlterModelOptions(
            name='unittransform',
            options={'verbose_name': 'Unit Transfrom', 'verbose_name_plural': 'Unit Transfroms'},
        ),
        migrations.AlterField(
            model_name='contact',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodifiedby',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='name',
            field=models.CharField(max_length=300, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultSupplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Default Supplier'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultcurrency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Default Currency'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultcustomer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Customer', verbose_name='Default Customer'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='description',
            field=models.TextField(verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_contractlstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relcontractstaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='description',
            field=models.CharField(max_length=100, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='rounding',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Rounding'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='shortName',
            field=models.CharField(max_length=3, verbose_name='Displayed Name After Price In The Position'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='defaultCustomerBillingCycle',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerBillingCycle', verbose_name='Default Billing Cycle'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='ismemberof',
            field=models.ManyToManyField(blank=True, to='crm.CustomerGroup', verbose_name='Is member of'),
        ),
        migrations.AlterField(
            model_name='customerbillingcycle',
            name='name',
            field=models.CharField(max_length=300, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='customerbillingcycle',
            name='timeToPaymentDate',
            field=models.IntegerField(verbose_name='Days To Payment Date'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='factor',
            field=models.IntegerField(blank=True, null=True, verbose_name='Factor between From and To Customer Group'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='fromCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromcustomergroup', to='crm.CustomerGroup', verbose_name='From Unit'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='toCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtocustomergroup', to='crm.CustomerGroup', verbose_name='To Unit'),
        ),
        migrations.AlterField(
            model_name='emailaddress',
            name='email',
            field=models.EmailField(max_length=200, verbose_name='Email Address'),
        ),
        migrations.AlterField(
            model_name='emailaddressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='emailaddressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='emailaddressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='emailaddressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='payableuntil',
            field=models.DateField(verbose_name='To pay until'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='paymentBankReference',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Payment Bank Reference'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='status',
            field=models.CharField(choices=[('P', 'Payed'), ('C', 'Invoice created'), ('I', 'Invoice sent'), ('F', 'First reminder sent'), ('R', 'Second reminder sent'), ('U', 'Customer cant pay'), ('D', 'Deleted')], max_length=1),
        ),
        migrations.AlterField(
            model_name='phoneaddress',
            name='phone',
            field=models.CharField(max_length=20, verbose_name='Phone Number'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='position',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='position',
            name='discount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Discount'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Price'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Tax'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Last Pricing Date'),
        ),
        migrations.AlterField(
            model_name='position',
            name='overwriteProductPrice',
            field=models.BooleanField(verbose_name='Overwrite Product Price'),
        ),
        migrations.AlterField(
            model_name='position',
            name='positionNumber',
            field=models.IntegerField(verbose_name='Position Number'),
        ),
        migrations.AlterField(
            model_name='position',
            name='positionPricePerUnit',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Price Per Unit'),
        ),
        migrations.AlterField(
            model_name='position',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='position',
            name='quantity',
            field=models.DecimalField(decimal_places=3, max_digits=10, verbose_name='Quantity'),
        ),
        migrations.AlterField(
            model_name='position',
            name='sentOn',
            field=models.DateField(blank=True, null=True, verbose_name='Shipment on'),
        ),
        migrations.AlterField(
            model_name='position',
            name='shipmentID',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Shipment ID'),
        ),
        migrations.AlterField(
            model_name='position',
            name='supplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Shipment Supplier'),
        ),
        migrations.AlterField(
            model_name='position',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline1',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 1'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline2',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 2'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline3',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 3'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline4',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 4'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='country',
            field=models.CharField(blank=True, choices=[('AF', 'Afghanistan'), ('AX', 'Aland Islands'), ('AL', 'Albania'), ('DZ', 'Algeria'), ('AS', 'American Samoa'), ('AD', 'Andorra'), ('AO', 'Angola'), ('AI', 'Anguilla'), ('AQ', 'Antarctica'), ('AG', 'Antigua and Barbuda'), ('AR', 'Argentina'), ('AM', 'Armenia'), ('AW', 'Aruba'), ('AU', 'Australia'), ('AT', 'Austria'), ('AZ', 'Azerbaijan'), ('BS', 'the Bahamas'), ('BH', 'Bahrain'), ('BD', 'Bangladesh'), ('BB', 'Barbados'), ('BY', 'Belarus'), ('BE', 'Belgium'), ('BZ', 'Belize'), ('BJ', 'Benin'), ('BM', 'Bermuda'), ('BT', 'Bhutan'), ('BO', 'Bolivia'), ('BA', 'Bosnia and Herzegovina'), ('BW', 'Botswana'), ('BV', 'Bouvet Island'), ('BR', 'Brazil'), ('IO', 'British Indian Ocean Territory'), ('BN', 'Brunei Darussalam'), ('BG', 'Bulgaria'), ('BF', 'Burkina Faso'), ('BI', 'Burundi'), ('KH', 'Cambodia'), ('CM', 'Cameroon'), ('CA', 'Canada'), ('CV', 'Cape Verde'), ('KY', 'Cayman Islands'), ('CF', 'Central African Republic'), ('TD', 'Chad'), ('CL', 'Chile'), ('CN', 'China'), ('CX', 'Christmas Island'), ('CC', 'Cocos (Keeling) Islands'), ('CO', 'Colombia'), ('KM', 'Comoros'), ('CG', 'Congo'), ('CD', 'Democratic Republic of the Congo'), ('CK', 'Cook Islands'), ('CR', 'Costa Rica'), ('CI', "Cote d'Ivoire"), ('HR', 'Croatia'), ('CU', 'Cuba'), ('CY', 'Cyprus'), ('CZ', 'Czech Republic'), ('DK', 'Denmark'), ('DJ', 'Djibouti'), ('DM', 'Dominica'), ('DO', 'Dominican Republic'), ('EC', 'Ecuador'), ('EG', 'Egypt'), ('SV', 'El Salvador'), ('GQ', 'Equatorial Guinea'), ('ER', 'Eritrea'), ('EE', 'Estonia'), ('ET', 'Ethiopia'), ('FK', 'Falkland Islands (Malvinas)'), ('FO', 'Faroe Islands'), ('FJ', 'Fiji'), ('FI', 'Finland'), ('FR', 'France'), ('GF', 'French Guiana'), ('PF', 'French Polynesia'), ('TF', 'French Southern and Antarctic Lands'), ('GA', 'Gabon'), ('GM', 'Gambia'), ('GE', 'Georgia'), ('DE', 'Germany'), ('GH', 'Ghana'), ('GI', 'Gibraltar'), ('GR', 'Greece'), ('GL', 'Greenland'), ('GD', 'Grenada'), ('GP', 'Guadeloupe'), ('GU', 'Guam'), ('GT', 'Guatemala'), ('GG', 'Guernsey'), ('GN', 'Guinea'), ('GW', 'Guinea-Bissau'), ('GY', 'Guyana'), ('HT', 'Haiti'), ('HM', 'Heard Island and McDonald Islands'), ('VA', 'Vatican City Holy See'), ('HN', 'Honduras'), ('HK', 'Hong Kong'), ('HU', 'Hungary'), ('IS', 'Iceland'), ('IN', 'India'), ('ID', 'Indonesia'), ('IR', 'Iran'), ('IQ', 'Iraq'), ('IE', 'Ireland'), ('IM', 'Isle of Man'), ('IL', 'Israel'), ('IT', 'Italy'), ('JM', 'Jamaica'), ('JP', 'Japan'), ('JE', 'Jersey'), ('JO', 'Jordan'), ('KZ', 'Kazakhstan'), ('KE', 'Kenya'), ('KI', 'Kiribati'), ('KP', 'North Korea'), ('KR', 'South Korea'), ('KW', 'Kuwait'), ('KG', 'Kyrgyzstan'), ('LA', 'Laos Lao'), ('LV', 'Latvia'), ('LB', 'Lebanon'), ('LS', 'Lesotho'), ('LR', 'Liberia'), ('LY', 'Libya Libyan Arab Jamahiriya'), ('LI', 'Liechtenstein'), ('LT', 'Lithuania'), ('LU', 'Luxembourg'), ('MO', 'Macau Macao'), ('MK', 'Macedonia'), ('MG', 'Madagascar'), ('MW', 'Malawi'), ('MY', 'Malaysia'), ('MV', 'Maldives'), ('ML', 'Mali'), ('MT', 'Malta'), ('MH', 'Marshall Islands'), ('MQ', 'Martinique'), ('MR', 'Mauritania'), ('MU', 'Mauritius'), ('YT', 'Mayotte'), ('MX', 'Mexico'), ('FM', 'Micronesia'), ('MD', 'Moldova'), ('MC', 'Monaco'), ('MN', 'Mongolia'), ('ME', 'Montenegro'), ('MS', 'Montserrat'), ('MA', 'Morocco'), ('MZ', 'Mozambique'), ('MM', 'Myanmar'), ('NA', 'Namibia'), ('NR', 'Nauru'), ('NP', 'Nepal'), ('NL', 'Netherlands'), ('AN', 'Netherlands Antilles'), ('NC', 'New Caledonia'), ('NZ', 'New Zealand'), ('NI', 'Nicaragua'), ('NE', 'Niger'), ('NG', 'Nigeria'), ('NU', 'Niue'), ('NF', 'Norfolk Island Norfolk Island'), ('MP', 'Northern Mariana Islands'), ('NO', 'Norway'), ('OM', 'Oman'), ('PK', 'Pakistan'), ('PW', 'Palau'), ('PS', 'Palestinian Territory'), ('PA', 'Panama'), ('PG', 'Papua New Guinea'), ('PY', 'Paraguay'), ('PE', 'Peru'), ('PH', 'Philippines'), ('PN', 'Pitcairn Islands'), ('PL', 'Poland'), ('PT', 'Portugal'), ('PR', 'Puerto Rico'), ('QA', 'Qatar'), ('RE', 'Reunion'), ('RO', 'Romania'), ('RU', 'Russia'), ('RW', 'Rwanda'), ('SH', 'Saint Helena'), ('KN', 'Saint Kitts and Nevis'), ('LC', 'Saint Lucia'), ('PM', 'Saint Pierre and Miquelon'), ('VC', 'Saint Vincent and the Grenadines'), ('WS', 'Samoa'), ('SM', 'San Marino'), ('ST', 'Sao Tome and Principe'), ('SA', 'Saudi Arabia'), ('SN', 'Senegal'), ('RS', 'Serbia'), ('SC', 'Seychelles'), ('SL', 'Sierra Leone'), ('SG', 'Singapore'), ('SK', 'Slovakia'), ('SI', 'Slovenia'), ('SB', 'Solomon Islands'), ('SO', 'Somalia'), ('ZA', 'South Africa'), ('GS', 'South Georgia and the South Sandwich Islands'), ('ES', 'Spain'), ('LK', 'Sri Lanka'), ('SD', 'Sudan'), ('SR', 'Suriname'), ('SJ', 'Svalbard and Jan Mayen'), ('SZ', 'Swaziland'), ('SE', 'Sweden'), ('CH', 'Switzerland'), ('SY', 'Syria'), ('TW', 'Taiwan'), ('TJ', 'Tajikistan'), ('TZ', 'Tanzania'), ('TH', 'Thailand'), ('TL', 'East Timor'), ('TG', 'Togo'), ('TK', 'Tokelau'), ('TO', 'Tonga'), ('TT', 'Trinidad and Tobago'), ('TN', 'Tunisia'), ('TR', 'Turkey'), ('TM', 'Turkmenistan'), ('TC', 'Turks and Caicos Islands'), ('TV', 'Tuvalu'), ('UG', 'Uganda'), ('UA', 'Ukraine'), ('AE', 'United Arab Emirates'), ('GB', 'United Kingdom'), ('US', 'United States'), ('UM', 'United States Minor Outlying Islands'), ('UY', 'Uruguay'), ('UZ', 'Uzbekistan'), ('VU', 'Vanuatu'), ('VE', 'Venezuela'), ('VN', 'Vietnam Viet Nam'), ('VG', 'British Virgin Islands'), ('VI', 'United States Virgin Islands'), ('WF', 'Wallis and Futuna'), ('EH', 'Western Sahara'), ('YE', 'Yemen'), ('ZM', 'Zambia'), ('ZW', 'Zimbabwe')], max_length=2, null=True, verbose_name='Country'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='prefix',
            field=models.CharField(blank=True, choices=[('F', 'Company'), ('W', 'Mrs'), ('H', 'Mr'), ('G', 'Ms')], max_length=1, null=True, verbose_name='Prefix'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='prename',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Prename'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='state',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='State'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='town',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='City'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='zipcode',
            field=models.IntegerField(blank=True, null=True, verbose_name='Zipcode'),
        ),
        migrations.AlterField(
            model_name='postaladdressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='postaladdressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='postaladdressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='postaladdressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='price',
            name='customerGroup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerGroup', verbose_name='Customer Group'),
        ),
        migrations.AlterField(
            model_name='price',
            name='price',
            field=models.DecimalField(decimal_places=2, max_digits=17, verbose_name='Price Per Unit'),
        ),
        migrations.AlterField(
            model_name='price',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='price',
            name='unit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='price',
            name='validfrom',
            field=models.DateField(blank=True, null=True, verbose_name='Valid from'),
        ),
        migrations.AlterField(
            model_name='price',
            name='validuntil',
            field=models.DateField(blank=True, null=True, verbose_name='Valid until'),
        ),
        migrations.AlterField(
            model_name='product',
            name='accoutingProductCategorie',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, to='accounting.ProductCategorie', verbose_name='Accounting Product Categorie'),
        ),
        migrations.AlterField(
            model_name='product',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='product',
            name='defaultunit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='product',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='product',
            name='productNumber',
            field=models.IntegerField(verbose_name='Product Number'),
        ),
        migrations.AlterField(
            model_name='product',
            name='title',
            field=models.CharField(max_length=200, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Currency'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='description',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='externalReference',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='External Reference'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Price With Tax'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Tax'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Last Pricing Date'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last printed'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_polstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relpostaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='status',
            field=models.CharField(choices=[('O', 'Ordered'), ('D', 'Delayed'), ('Y', 'Delivered'), ('I', 'Invoice registered'), ('P', 'Invoice payed')], max_length=1),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='supplier',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Supplier'),
        ),
        migrations.AlterField(
            model_name='purchaseorderposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='status',
            field=models.CharField(choices=[('S', 'Success'), ('I', 'Quote created'), ('Q', 'Quote sent'), ('F', 'First reminder sent'), ('R', 'Second reminder sent'), ('D', 'Deleted')], max_length=1, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='validuntil',
            field=models.DateField(verbose_name='Valid until'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Currency'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='customer',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Customer', verbose_name='Customer'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='description',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='discount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Discount'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='externalReference',
            field=models.CharField(blank=True, max_length=100, verbose_name='External Reference'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Price without Tax '),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Tax'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Pricing Date'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last printed'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_lstscmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relscstaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AlterField(
            model_name='salescontractposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='accountActiva',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relaccountactiva', to='accounting.Account', verbose_name='Activa Account'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='accountPassiva',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relaccountpassiva', to='accounting.Account', verbose_name='Passiva Account'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='name',
            field=models.CharField(max_length=100, verbose_name='Taxname'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='taxrate',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Taxrate in Percentage'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='description',
            field=models.CharField(max_length=100, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='fractionFactorToNextHigherUnit',
            field=models.IntegerField(blank=True, null=True, verbose_name='Factor Between This And Next Higher Unit'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='isAFractionOf',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Is A Fraction Of'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='shortName',
            field=models.CharField(max_length=3, verbose_name='Displayed Name After Quantity In The Position'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='factor',
            field=models.IntegerField(blank=True, null=True, verbose_name='Factor between From and To Unit'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='fromUnit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromunit', to='crm.Unit', verbose_name='From Unit'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='toUnit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtounit', to='crm.Unit', verbose_name='To Unit'),
        ),
    ]
