# Generated by Django 2.1.4 on 2018-12-16 22:24

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0009_auto_20181012_2056'),
    ]

    operations = [
        migrations.AlterField(
            model_name='booking',
            name='last_modified_by',
            field=models.ForeignKey(blank=True, limit_choices_to={'is_staff': True}, on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_lstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='staff',
            field=models.ForeignKey(blank=True, limit_choices_to={'is_staff': True}, on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_refstaff', to=settings.AUTH_USER_MODEL, verbose_name='Reference Staff'),
        ),
        migrations.AlterField(
            model_name='productcategory',
            name='loss_account',
            field=models.ForeignKey(limit_choices_to={'account_type': 'S'}, on_delete=django.db.models.deletion.CASCADE, related_name='db_loss_account', to='accounting.Account', verbose_name='Loss Account'),
        ),
        migrations.AlterField(
            model_name='productcategory',
            name='profit_account',
            field=models.ForeignKey(limit_choices_to={'account_type': 'E'}, on_delete=django.db.models.deletion.CASCADE, related_name='db_profit_account', to='accounting.Account', verbose_name='Profit Account'),
        ),
    ]
