# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-11 20:31
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ('crm', '0017_auto_20180111_2022'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='textparagraphinsalesdocument',
            options={'verbose_name': 'Text Paragraph In Sales Document', 'verbose_name_plural': 'Text Paragraphs In Sales Documents'},
        ),
        migrations.RenameField(
            model_name='deliverynote',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='emailaddressforsalesdocument',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='invoice',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='paymentreminder',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='phoneaddressforsalesdocument',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='postaladdressforsalesdocument',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='purchaseconfirmation',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='quote',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='salesdocumentposition',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='textparagraphinsalesdocument',
            old_name='sales_contract',
            new_name='sales_document',
        ),
    ]
