# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-10 17:32
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0002_auto_20171009_1949'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='templateset',
            options={'verbose_name': 'Templateset', 'verbose_name_plural': 'Templatesets'},
        ),
        migrations.AlterModelOptions(
            name='userextension',
            options={'verbose_name': 'User Extention', 'verbose_name_plural': 'User Extentions'},
        ),
        migrations.AlterModelOptions(
            name='xslfile',
            options={'verbose_name': 'XSL File', 'verbose_name_plural': 'XSL Files'},
        ),
        migrations.AddField(
            model_name='templateset',
            name='reminder1XSLFile',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepaymentreminder1', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Payment Reminder 1'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='reminder2XSLFile',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepaymentreminder2', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Payment Reminder 2'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='addresser',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addresser'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='balancesheetXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatebalancesheet', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Balancesheet'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='bankingaccountref',
            field=models.CharField(blank=True, max_length=60, null=True, verbose_name='Reference to Banking Account'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='deilveryorderXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatedeliveryorder', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Deilvery Order'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='footerTextpurchaseorders',
            field=models.TextField(blank=True, null=True, verbose_name='Footer Text On Purchaseorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='footerTextsalesorders',
            field=models.TextField(blank=True, null=True, verbose_name='Footer Text On Salesorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='fopConfigurationFile',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='FOP Configuration File'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='headerTextpurchaseorders',
            field=models.TextField(blank=True, null=True, verbose_name='Header Text On Purchaseorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='headerTextsalesorders',
            field=models.TextField(blank=True, null=True, verbose_name='Header Text On Salesorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='invoiceXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplateinvoice', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Invoice'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='logo',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='Logo for the PDF generation'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='organisationname',
            field=models.CharField(max_length=200, verbose_name='Name of the Organisation'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='pagefooterleft',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='Page Footer Left'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='pagefootermiddle',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='Page Footer Middle'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='profitLossStatementXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplateprofitlossstatement', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Profit Loss Statement'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='purchaseorderXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepurchaseorder', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Purchaseorder'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='quoteXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatequote', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Quote'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='title',
            field=models.CharField(max_length=100, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='userextensionemailaddress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='userextensionphoneaddress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='userextensionpostaladdress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='xslfile',
            name='title',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='xslfile',
            name='xslfile',
            field=filebrowser.fields.FileBrowseField(max_length=200, verbose_name='XSL File'),
        ),
    ]
