# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-04 21:38
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0009_auto_20180104_2111'),
    ]

    operations = [
        migrations.RenameField(
            model_name='position',
            old_name='positionPricePerUnit',
            new_name='position_price_per_unit',
        ),
    ]
