# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-10-12 20:56
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0053_auto_20181014_2305'),
        ('accounting', '0008_auto_20181012_2056'),
    ]

    operations = [
        migrations.DeleteModel(
            name='ProductCategorie',
        ),
        migrations.AddField(
            model_name='productcategory',
            name='loss_account',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_loss_account', to='accounting.Account', verbose_name='Loss Account'),
        ),
        migrations.AddField(
            model_name='productcategory',
            name='profit_account',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_profit_account', to='accounting.Account', verbose_name='Profit Account'),
        ),
    ]
