# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-19 21:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0022_auto_20180117_2020'),
    ]

    operations = [
        migrations.AlterField(
            model_name='position',
            name='position_number',
            field=models.PositiveIntegerField(verbose_name='Position Number'),
        ),
    ]
