"""
Django settings for test_koalixcrm project.

Generated by 'django-admin startproject' using Django 1.11.3.

For more information on this file, see
https://docs.djangoproject.com/en/1.11/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.11/ref/settings/
"""
from .base_settings import *

# Update database configuration with $DATABASE_URL.
import dj_database_url
DATABASES = { 'default': dj_database_url.config(conn_max_age=500) }
FOP_EXECUTABLE = "/usr/bin/fop"
GRAPPELLI_INDEX_DASHBOARD = 'projectsettings.dashboard.CustomIndexDashboard'
ALLOWED_HOSTS = ['koalix-crm.herokuapp.com']

KOALIXCRM_REST_API_AUTH = True
