# -*- coding: utf-8 -*

from django.utils.translation import ugettext as _

PURPOSESADDRESSINUSEREXTENTION = (
    ('H', _('Private')),
    ('O', _('Business')),
    ('P', _('Mobile Private')),
    ('B', _('Mobile Business')),
)
