# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-07-02 16:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0037_auto_20180701_2128'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='postaladdress',
            name='addressline1',
        ),
        migrations.RemoveField(
            model_name='postaladdress',
            name='addressline2',
        ),
        migrations.RemoveField(
            model_name='postaladdress',
            name='addressline3',
        ),
        migrations.RemoveField(
            model_name='postaladdress',
            name='addressline4',
        ),
        migrations.RemoveField(
            model_name='postaladdress',
            name='prename',
        ),
        migrations.RemoveField(
            model_name='postaladdress',
            name='zipcode',
        ),
        migrations.AddField(
            model_name='postaladdress',
            name='address_line_1',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Address line 1'),
        ),
        migrations.AddField(
            model_name='postaladdress',
            name='address_line_2',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Address line 2'),
        ),
        migrations.AddField(
            model_name='postaladdress',
            name='address_line_3',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Address line 3'),
        ),
        migrations.AddField(
            model_name='postaladdress',
            name='address_line_4',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Address line 4'),
        ),
        migrations.AddField(
            model_name='postaladdress',
            name='pre_name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Pre-name'),
        ),
        migrations.AddField(
            model_name='postaladdress',
            name='zip_code',
            field=models.IntegerField(blank=True, null=True, verbose_name='Zip Code'),
        ),
    ]
