# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-10 17:32
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions', '0002_auto_20171009_1949'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subscription',
            options={'verbose_name': 'Subscription', 'verbose_name_plural': 'Subscriptions'},
        ),
        migrations.AlterModelOptions(
            name='subscriptionevent',
            options={'verbose_name': 'Subscription Event', 'verbose_name_plural': 'Subscription Events'},
        ),
        migrations.AlterModelOptions(
            name='subscriptiontype',
            options={'verbose_name': 'Subscription Type', 'verbose_name_plural': 'Subscription Types'},
        ),
        migrations.AlterField(
            model_name='subscription',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Subscription Type'),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='subscriptiontype',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='subscriptions.SubscriptionType', verbose_name='Subscription Type'),
        ),
        migrations.AlterField(
            model_name='subscriptionevent',
            name='event',
            field=models.CharField(choices=[('O', 'Offered'), ('C', 'Canceled'), ('S', 'Signed')], max_length=1, verbose_name='Event'),
        ),
        migrations.AlterField(
            model_name='subscriptionevent',
            name='eventdate',
            field=models.DateField(blank=True, null=True, verbose_name='Event Date'),
        ),
        migrations.AlterField(
            model_name='subscriptionevent',
            name='subscriptions',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='subscriptions.Subscription', verbose_name='Subscription'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='automaticContractExtension',
            field=models.IntegerField(blank=True, null=True, verbose_name='Automatic Contract Extension (months)'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='automaticContractExtensionReminder',
            field=models.IntegerField(blank=True, null=True, verbose_name='Automatic Contract Extensoin Reminder (days)'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='cancelationPeriod',
            field=models.IntegerField(blank=True, null=True, verbose_name='Cancelation Period (months)'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='contractDocument',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='Contract Documents'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='minimumDuration',
            field=models.IntegerField(blank=True, null=True, verbose_name='Minimum Contract Duration'),
        ),
        migrations.AlterField(
            model_name='subscriptiontype',
            name='paymentIntervall',
            field=models.IntegerField(blank=True, null=True, verbose_name='Payment Intervall (days)'),
        ),
    ]
