# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-06-11 19:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0028_auto_20180611_1835'),
    ]

    operations = [
        migrations.AlterField(
            model_name='generictasklink',
            name='task_link_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.TaskLinkType', verbose_name='Task Link Type'),
        ),
    ]
