# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-12-10 21:26
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0003_auto_20171110_1732'),
    ]

    operations = [
        migrations.CreateModel(
            name='DocumentTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Title')),
                ('xsl_file', filebrowser.fields.FileBrowseField(max_length=200, verbose_name='XSL File')),
                ('fop_config_file', filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='FOP Configuration File')),
                ('logo', filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='Logo for the PDF generation')),
            ],
            options={
                'verbose_name': 'Document template',
                'verbose_name_plural': 'Document templates',
            },
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='addresser',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='balancesheetXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='bankingaccountref',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='deilveryorderXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='footerTextpurchaseorders',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='footerTextsalesorders',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='fopConfigurationFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='headerTextpurchaseorders',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='headerTextsalesorders',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='invoiceXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='logo',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='organisationname',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='pagefooterleft',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='pagefootermiddle',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='profitLossStatementXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='purchaseconfirmationXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='purchaseorderXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='quoteXSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='reminder1XSLFile',
        ),
        migrations.RemoveField(
            model_name='templateset',
            name='reminder2XSLFile',
        ),
        migrations.CreateModel(
            name='BalanceSheetTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Balance sheet template',
                'verbose_name_plural': 'Balance sheet templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='DeliveryNoteTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Delivery note template',
                'verbose_name_plural': 'Delivery note templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='InvoiceTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Invoice template',
                'verbose_name_plural': 'Invoice templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='PaymentReminderTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Payment reminder template',
                'verbose_name_plural': 'Payment reminder templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='ProfitLossStatementTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Profit loss statement template',
                'verbose_name_plural': 'Profit loss statement templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='PurchaseConfirmationTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Purchase confirmation template',
                'verbose_name_plural': 'Purchase confirmation templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='PurchaseOrderTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Purchase order template',
                'verbose_name_plural': 'Purchase order templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.CreateModel(
            name='QuoteTemplate',
            fields=[
                ('documenttemplate_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djangoUserExtension.DocumentTemplate')),
            ],
            options={
                'verbose_name': 'Quote template',
                'verbose_name_plural': 'Quote templates',
            },
            bases=('djangoUserExtension.documenttemplate',),
        ),
        migrations.DeleteModel(
            name='XSLFile',
        ),
        migrations.AddField(
            model_name='templateset',
            name='balance_sheet_statement_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.BalanceSheetTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='delivery_note_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.DeliveryNoteTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='invoice_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.InvoiceTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='payment_reminder_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.PaymentReminderTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='profit_loss_statement_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.ProfitLossStatementTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='purchase_confirmation_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.PurchaseConfirmationTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='purchase_order_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.PurchaseOrderTemplate'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='quote_template',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djangoUserExtension.QuoteTemplate'),
        ),
    ]
